import Items from './views/Items';
import Boxes from './views/Boxes';
import Files from './views/Files';
import Events from './views/Events';
import Error from './views/Error';
import HowTo from './views/HowTo';
import VueRouter from 'vue-router';
import Vue from 'vue';
import Login from '@/views/Login.vue';
import Register from '@/views/Register.vue';
import Debug from "@/views/admin/Debug.vue";
import Tickets from "@/views/Tickets.vue";
import Ticket from "@/views/Ticket.vue";
import Admin from "@/views/admin/Admin.vue";
import store from "@/store";

Vue.use(VueRouter);

const routes = [
    {path: '/', redirect: '/Camp23/items', meta: {requiresAuth: false}},
    {path: '/login', name: 'login', component: Login, meta: {requiresAuth: false}},
    {path: '/register', name: 'register', component: Register, meta: {requiresAuth: false}},
    {path: '/howto', name: 'howto', component: HowTo, meta: {requiresAuth: true}},
    {path: '/:event/boxes', name: 'boxes', component: Boxes, meta: {requiresAuth: true}},
    {path: '/:event/items', name: 'items', component: Items, meta: {requiresAuth: true}},
    {path: '/:event/box/:uid', name: 'box', component: Boxes, meta: {requiresAuth: true}},
    {path: '/:event/item/:uid', name: 'item', component: Items, meta: {requiresAuth: true}},
    {path: '/:event/tickets', name: 'tickets', component: Tickets, meta: {requiresAuth: true}},
    {path: '/:event/ticket/:id', name: 'ticket', component: Ticket, meta: {requiresAuth: true}},
    {path: '/admin', name: 'admin', component: Admin, meta: {requiresAuth: true}},
    {path: '/admin/files', name: 'files', component: Files, meta: {requiresAuth: true}},
    {path: '/admin/events', name: 'events', component: Events, meta: {requiresAuth: true}},
    {path: '/admin/debug', name: 'debug', component: Debug, meta: {requiresAuth: true}},
    {path: '/admin/users', name: 'users', component: Events, meta: {requiresAuth: true}},
    {path: '*', component: Error},
];

const router = new VueRouter({
    mode: 'history',
    routes,
});

//router.beforeEach((to/*, from*/, next) => {
//    console.log("beforeEach", to);
//    if (to.meta.requiresAuth && !store.getters.isLoggedIn) {
//        console.log("Not logged in, redirecting to login page")
//        return {
//            name: 'login',
//            query: {redirect: to.fullPath},
//        }
//    }
//});

//router.beforeResolve((to, from, next) => {
//    next()
//});

router.beforeEach((to, from, next) => {
    if (to.meta.requiresAuth && !store.getters.isLoggedIn) {
        //console.log("Not logged in, redirecting to login page")
        next({
            name: 'login',
            query: {redirect: to.fullPath},
        })
    } else {
        next()
    }
});

router.afterEach((to/*, from*/) => {
    if (to.params.event) {
        //console.log('update last event', to.params.event);
        store.commit('updateLastEvent', to.params.event);
    }
});

export default router;
